| BRANCH | STATUS |
|---|---|
| main | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/pod-porter/actions/workflows/test-coverage-lint.yml/badge.svg?branch=main)](https://github.com/btr1975/pod-porter/actions/workflows/test-coverage-lint.yml) |
| develop | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/pod-porter/actions/workflows/test-coverage-lint.yml/badge.svg?branch=develop)](https://github.com/btr1975/pod-porter/actions/workflows/test-coverage-lint.yml) |

[![Supported Versions](https://img.shields.io/pypi/pyversions/pod-porter.svg)](https://pypi.org/project/pod-porter)

[![Docs](https://readthedocs.org/projects/pod-porter/badge/?version=latest)](https://pod-porter.readthedocs.io/en/latest/)

[![PyPI Downloads](https://static.pepy.tech/badge/pod-porter)](https://pepy.tech/project/pod-porter)

# pod-porter

## Description
* Like Helm but for Container Compose Files
* [Some Porter Examples](https://github.com/btr1975/automation-framework/tree/main/porter)

#### Generated by CookieCutter
* Repository: [GitHub](https://github.com/btr1975/cookiecutter-python-library)
* Version: 1.0.14


### "Map" Structure

```text

map-name
    ├── Map.yaml
    ├── values.yaml
    ├── templates

```
